==> fwdi-0.0.83.tar.gz: fwdi-0.0.83/fwdi/WebApp/web_application_builder.py <==
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\

# Licensed under the MIT License <http://opensource.org/licenses/MIT>
# SPDX-License-Identifier: MIT
# Copyright (c) 2020-2021 The Alitrix Authors <http://github.com/Alitrix>

from typing import TypeVar
from fastapi.security import OAuth2PasswordBearer

from ..Application.Abstractions.base_service_collection import BaseServiceCollectionFWDI
from ..Application.DependencyInjection.resolve_provider import ResolveProviderFWDI
from ..Application.DependencyInjection.service_collection import ServiceCollectionFWDI
from ..Infrastructure.JwtService.jwt_service import JwtServiceFWDI
from ..Persistence.default_init_db import DefaultInitializeDB
from ..Utilites.system_logging import SysLogging, TypeLogging
from ..Domain.Configure.global_setting_service import GlobalSettingService

T = TypeVar('T')


class WebApplicationBuilder():
    def __init__(self, obj:T) -> None:
        self.__log__ = SysLogging(logging_level=TypeLogging.DEBUG, filename='WebApplicationBuilder')
        self.__log__(f"{__name__}:{obj}")
        self.__instance_app:type[T] = obj
        self.services:BaseServiceCollectionFWDI = ServiceCollectionFWDI()
        self.__scopes:dict[str, str] = {}
        self.__is_build:bool = False

    def build(self)-> type[T]:
        if self.__is_build:
            raise Exception('Error is already build.')
        
        self.__log__(f"Build services")
        from ..Presentation.dependency_injection import DependencyInjection as DependencyInjectionPresentation
        from ..Utilites.dependency_injection import DependencyInjection as DependencyInjectionUtilites
        
        self.__instance_app.instance = self
        self.__instance_app.resolver = ResolveProviderFWDI(self.services.GenerateContainer(), self.__instance_app.Debug)
        
        #---------------------- DEFAULT WEB CONTROLLER SERVICES ------------------------------------
        self.__log__(f"Create dependency injection Utilites")
        DependencyInjectionUtilites.AddUtilites(self.services)
        self.__log__(f"Create dependency injection Presentation")
        DependencyInjectionPresentation.AddPresentation(self.__instance_app)

        #---------------------- /DEFAULT WEB CONTROLLER SERVICES -----------------------------------
        self.__log__(f"Inititalize OAuth2PasswordBearer: scope:{self.__scopes}")
        JwtServiceFWDI.oauth2_scheme = OAuth2PasswordBearer(tokenUrl="token", scopes=self.__scopes,) if len(self.__scopes) > 0 else OAuth2PasswordBearer(tokenUrl="token")
        self.__log__(f"Inititalize DB")
        DefaultInitializeDB.init_db(self.__scopes)
        self.__is_build = True
        return self.__instance_app
    
    def add_scope(self, scopes:dict[str,str]):
        if self.__is_build:
            raise Exception('Error add dependency after build')
        
        for item in scopes.items():
            if not item in self.__scopes:
                self.__scopes[item[0]] = item[1]
    
    def add_health_checks(self):
        if self.__is_build:
            raise Exception('Error add dependency after build')
        
        from ..Presentation.dependency_injection import DependencyInjection as DependencyInjectionPresentation
        DependencyInjectionPresentation.AddHealthChecks(self.__instance_app)

==> fwdi-0.1.1.tar.gz: fwdi-0.1.1/fwdi/WebApp/web_application_builder.py <==
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\

# Licensed under the MIT License <http://opensource.org/licenses/MIT>
# SPDX-License-Identifier: MIT
# Copyright (c) 2020-2021 The Alitrix Authors <http://github.com/Alitrix>

from typing import TypeVar
from fastapi.security import OAuth2PasswordBearer

from ..Application.Logging.manager_logging import ManagerLogging
from ..Application.Abstractions.base_service_collection import BaseServiceCollectionFWDI
from ..Application.DependencyInjection.resolve_provider import ResolveProviderFWDI
from ..Application.DependencyInjection.service_collection import ServiceCollectionFWDI
from ..Infrastructure.JwtService.jwt_service import JwtServiceFWDI
from ..Persistence.default_init_db import DefaultInitializeDB

T = TypeVar('T')


class WebApplicationBuilder():
    def __init__(self, web_app_inst:T) -> None:
        self.__log__ = ManagerLogging.get_logging('WebApplicationBuilder', web_app_inst._config_log)
        self.__log__(f"{__name__}:{web_app_inst}")
        self.__instance_app:type[T] = web_app_inst
        self.services:BaseServiceCollectionFWDI = ServiceCollectionFWDI()
        self.__scopes:dict[str, str] = {}
        self.__is_build:bool = False

    def build(self)-> type[T]:
        if self.__is_build:
            raise Exception('Error is already build.')
        
        self.__log__(f"Build services")
        from ..Presentation.dependency_injection import DependencyInjection as DependencyInjectionPresentation
        from ..Utilites.dependency_injection import DependencyInjection as DependencyInjectionUtilites
        
        self.__instance_app.instance = self
        self.__instance_app.resolver = ResolveProviderFWDI(self.services.GenerateContainer())
        
        #---------------------- DEFAULT WEB CONTROLLER SERVICES ------------------------------------
        self.__log__(f"Create dependency injection Utilites")
        DependencyInjectionUtilites.AddUtilites(self.services)
        self.__log__(f"Create dependency injection Presentation")
        DependencyInjectionPresentation.AddPresentation(self.__instance_app)

        #---------------------- /DEFAULT WEB CONTROLLER SERVICES -----------------------------------
        self.__log__(f"Inititalize OAuth2PasswordBearer: scope:{self.__scopes}")
        JwtServiceFWDI.oauth2_scheme = OAuth2PasswordBearer(tokenUrl="token", scopes=self.__scopes,) if len(self.__scopes) > 0 else OAuth2PasswordBearer(tokenUrl="token")
        self.__log__(f"Inititalize DB")
        DefaultInitializeDB.init_db(self.__scopes)
        self.__is_build = True
        return self.__instance_app
    
    def add_scope(self, scopes:dict[str,str]):
        if self.__is_build:
            raise Exception('Error add dependency after build')
        
        for item in scopes.items():
            if not item in self.__scopes:
                self.__scopes[item[0]] = item[1]
    
    def add_health_checks(self):
        if self.__is_build:
            raise Exception('Error add dependency after build')
        
        from ..Presentation.dependency_injection import DependencyInjection as DependencyInjectionPresentation
        DependencyInjectionPresentation.AddHealthChecks(self.__instance_app)
